@@ -29,7 +29,6 @@
 
 #include "ide-debug.h"
 #include "ide-global.h"
-#include "ide-macros.h"
 #include "ide-resources.h"
 
 #include "application/ide-application.h"
@@ -66,6 +65,15 @@
 G_DEFINE_TYPE (IdeApplication, ide_application, DZL_TYPE_APPLICATION)
 
 static GThread *main_thread;
+static const gchar *legacy_dirs[] = {
+  "buffers",
+  "builds",
+  "code-index",
+  "flatpak",
+  "install",
+  "tags",
+  NULL,
+};
 
 void
 _ide_application_set_mode (IdeApplication     *self,
@@ -388,6 +396,85 @@ ide_application_register_settings (IdeApplication *self)
   IDE_EXIT;
 }
 
+static GFile *
+build_legacy_cache_directory (const gchar *name)
+{
+  return g_file_new_build_filename (g_get_user_cache_dir (),
+                                    ide_get_program_name (),
+                                    name,
+                                    NULL);
+}
+
+static void
+ide_application_reap_legacy_cb (GObject      *object,
+                                GAsyncResult *result,
+                                gpointer      user_data)
+{
+  DzlDirectoryReaper *reaper = (DzlDirectoryReaper *)object;
+  g_autoptr(IdeApplication) self = user_data;
+  g_autoptr(GError) error = NULL;
+
+  IDE_ENTRY;
+
+  g_assert (DZL_IS_DIRECTORY_REAPER (reaper));
+  g_assert (G_IS_ASYNC_RESULT (result));
+  g_assert (IDE_IS_APPLICATION (self));
+
+  if (!dzl_directory_reaper_execute_finish (reaper, result, &error))
+    {
+      g_warning ("Failure reaping legacy data: %s", error->message);
+      IDE_EXIT;
+    }
+
+  for (guint i = 0; legacy_dirs[i] != NULL; i++)
+    {
+      g_autoptr(GFile) directory = NULL;
+      const gchar *name = legacy_dirs[i];
+
+      directory = build_legacy_cache_directory (name);
+      g_file_delete_async (directory, G_PRIORITY_LOW, NULL, NULL, NULL);
+    }
+
+  IDE_EXIT;
+}
+
+/*
+ * _ide_application_reap_legacy:
+ *
+ * This is meant to remove a bunch of legacy directories we no longer use.
+ * Since it can take a while, we do it in the background at startup if we
+ * discover they are there.
+ */
+static void
+_ide_application_reap_legacy (IdeApplication *self)
+{
+  g_autoptr(DzlDirectoryReaper) reaper = NULL;
+
+  IDE_ENTRY;
+
+  g_assert (IDE_IS_APPLICATION (self));
+
+  reaper = dzl_directory_reaper_new ();
+
+  /* Cleanup a number of old directories no longer used */
+  for (guint i = 0; legacy_dirs[i] != NULL; i++)
+    {
+      g_autoptr(GFile) directory = NULL;
+      const gchar *name = legacy_dirs[i];
+
+      directory = build_legacy_cache_directory (name);
+      dzl_directory_reaper_add_directory (reaper, directory, 0);
+    }
+
+  /* Do this asynchronously so we don't block the program at shutdown. */
+  dzl_directory_reaper_execute_async (reaper,
+                                      NULL,
+                                      ide_application_reap_legacy_cb,
+                                      g_object_ref (self));
+
+  IDE_EXIT;
+}
+
 static void
 ide_application_startup (GApplication *application)
 {
@@ -418,6 +505,7 @@ ide_application_startup (GApplication *application)
       ide_application_actions_init (self);
       _ide_application_init_shortcuts (self);
       _ide_application_init_color (self);
+      _ide_application_reap_legacy (self);
 
       modeline_parser_init ();
     }
@@ -449,6 +537,14 @@ ide_application_open (GApplication  *application,
                               NULL);
 }
 
+static gboolean
+ide_application_force_exit_timeout (gpointer data)
+{
+  g_warning ("Plugin caught spinning, forcing exit immediately");
+  exit (EXIT_FAILURE);
+  return G_SOURCE_REMOVE;
+}
+
 static void
 ide_application_shutdown (GApplication *application)
 {
@@ -467,13 +563,22 @@ ide_application_shutdown (GApplication *application)
   for (guint i = 0; i < self->reapers->len; i++)
     {
       DzlDirectoryReaper *reaper = g_ptr_array_index (self->reapers, i);
+      g_autoptr(GError) error = NULL;
 
       g_assert (DZL_IS_DIRECTORY_REAPER (reaper));
 
-      dzl_directory_reaper_execute (reaper, NULL, NULL);
+      if (!dzl_directory_reaper_execute (reaper, NULL, &error))
+        g_warning ("Failed to reap files: %s", error->message);
     }
 
   _ide_battery_monitor_shutdown ();
+
+  /* In case a plugin causes us to spin at shutdown, make sure that we
+   * force exit to avoid spinning in the background.
+   */
+  gdk_threads_add_timeout (3000, /* 3 seconds */
+                           ide_application_force_exit_timeout,
+                           NULL);
 }
 
 static void
@@ -610,7 +715,7 @@ ide_application_get_worker_cb (GObject      *object,
 {
   IdeWorkerManager *worker_manager = (IdeWorkerManager *)object;
   g_autoptr(GTask) task = user_data;
-  GError *error = NULL;
+  g_autoptr(GError) error = NULL;
   GDBusProxy *proxy;
 
   g_assert (IDE_IS_WORKER_MANAGER (worker_manager));
@@ -618,7 +723,7 @@ ide_application_get_worker_cb (GObject      *object,
   proxy = ide_worker_manager_get_worker_finish (worker_manager, result, &error);
 
   if (proxy == NULL)
-    g_task_return_error (task, error);
+    g_task_return_error (task, g_steal_pointer (&error));
   else
     g_task_return_pointer (task, proxy, g_object_unref);
 }
@@ -739,7 +844,7 @@ ide_application_show_projects_window (IdeApplication *self)
 
           name = ide_workbench_get_visible_perspective_name (IDE_WORKBENCH (window));
 
-          if (ide_str_equal0 ("greeter", name))
+          if (dzl_str_equal0 ("greeter", name))
             {
               gtk_window_present (windows->data);
               return;
