@@ -317,7 +317,7 @@ ide_buffer_manager_set_focus_buffer (IdeBufferManager *self,
 
   previous = self->focus_buffer;
 
-  if (ide_set_weak_pointer (&self->focus_buffer, buffer))
+  if (dzl_set_weak_pointer (&self->focus_buffer, buffer))
     {
       /* notify that we left the previous buffer */
       if (previous)
@@ -586,6 +586,8 @@ ide_buffer_manager_load_file__load_cb (GObject      *object,
           g_task_return_error (task, g_steal_pointer (&error));
           IDE_EXIT;
         }
+
+      g_clear_error (&error);
     }
 
   gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (state->buffer), FALSE);
@@ -641,8 +643,8 @@ ide_buffer_manager__load_file_query_info_cb (GObject      *object,
   GFile *file = (GFile *)object;
   g_autoptr(GTask) task = user_data;
   g_autoptr(GFileInfo) file_info = NULL;
+  g_autoptr(GError) error = NULL;
   LoadState *state;
-  GError *error = NULL;
   gsize size = 0;
   gboolean create_new_view = FALSE;
 
@@ -660,13 +662,14 @@ ide_buffer_manager__load_file_query_info_cb (GObject      *object,
 
   file_info = g_file_query_info_finish (file, result, &error);
 
-  if (!file_info)
+  if (file_info == NULL)
     {
       if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
         {
-          g_task_return_error (task, error);
+          g_task_return_error (task, g_steal_pointer (&error));
           IDE_EXIT;
         }
+      g_clear_error (&error);
     }
   else
     {
@@ -988,6 +991,7 @@ ide_buffer_manager_save_file__save_cb (GObject      *object,
                                        gpointer      user_data)
 {
   g_autoptr(GTask) task = user_data;
+  g_autoptr(GError) error = NULL;
   GtkSourceFileSaver *saver = (GtkSourceFileSaver *)object;
   IdeBufferManager *self;
   IdeUnsavedFiles *unsaved_files;
@@ -997,7 +1001,6 @@ ide_buffer_manager_save_file__save_cb (GObject      *object,
   GFile *gfile;
   GFile *old_gfile;
   SaveState *state;
-  GError *error = NULL;
 
   g_assert (GTK_SOURCE_IS_FILE_SAVER (saver));
   g_assert (G_IS_TASK (task));
@@ -1014,7 +1017,7 @@ ide_buffer_manager_save_file__save_cb (GObject      *object,
   /* Complete the save request */
   if (!gtk_source_file_saver_save_finish (saver, result, &error))
     {
-      g_task_return_error (task, error);
+      g_task_return_error (task, g_steal_pointer (&error));
       return;
     }
 
@@ -1065,7 +1068,7 @@ ide_buffer_manager_save_file__load_settings_cb (GObject      *object,
   GtkSourceNewlineType newline_type;
   const GtkSourceEncoding *encoding;
   const gchar *charset;
-  GError *error = NULL;
+  g_autoptr(GError) error = NULL;
 
   IDE_ENTRY;
 
@@ -1076,7 +1079,7 @@ ide_buffer_manager_save_file__load_settings_cb (GObject      *object,
 
   if (!file_settings)
     {
-      g_task_return_error (task, error);
+      g_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
@@ -1367,7 +1370,7 @@ ide_buffer_manager_dispose (GObject *object)
 {
   IdeBufferManager *self = (IdeBufferManager *)object;
 
-  ide_clear_weak_pointer (&self->focus_buffer);
+  dzl_clear_weak_pointer (&self->focus_buffer);
 
   while (self->buffers->len)
     {
@@ -1696,8 +1699,8 @@ register_auto_save (IdeBufferManager *self,
       AutoSave *state;
 
       state = g_slice_new0 (AutoSave);
-      ide_set_weak_pointer (&state->buffer, buffer);
-      ide_set_weak_pointer (&state->self, self);
+      dzl_set_weak_pointer (&state->buffer, buffer);
+      dzl_set_weak_pointer (&state->self, self);
       state->source_id = g_timeout_add_seconds (self->auto_save_timeout,
                                                 ide_buffer_manager_auto_save_cb,
                                                 state);
@@ -1719,9 +1722,9 @@ unregister_auto_save (IdeBufferManager *self,
   if (state != NULL)
     {
       g_hash_table_remove (self->timeouts, buffer);
-      ide_clear_source (&state->source_id);
-      ide_clear_weak_pointer (&state->buffer);
-      ide_clear_weak_pointer (&state->self);
+      dzl_clear_source (&state->source_id);
+      dzl_clear_weak_pointer (&state->buffer);
+      dzl_clear_weak_pointer (&state->self);
       g_slice_free (AutoSave, state);
     }
 }
@@ -2180,6 +2183,7 @@ ide_buffer_manager_apply_edits_buffer_loaded (GObject      *object,
           g_task_return_error (task, g_steal_pointer (&error));
           return;
         }
+      g_clear_error (&error);
     }
 
   /* Nothing to do if we already failed */
