@@ -196,7 +196,7 @@ ide_buffer_delay_settling (IdeBuffer *self)
 
   g_assert (IDE_IS_BUFFER (self));
 
-  ide_clear_source (&priv->settling_handler);
+  dzl_clear_source (&priv->settling_handler);
   priv->settling_handler = gdk_threads_add_timeout (SETTLING_DELAY_MSEC,
                                                     ide_buffer_settled_cb,
                                                     self);
@@ -634,7 +634,7 @@ ide_buffer_reload_change_monitor (IdeBuffer *self)
 
   if (priv->change_monitor)
     {
-      ide_clear_signal_handler (priv->change_monitor, &priv->change_monitor_changed_handler);
+      dzl_clear_signal_handler (priv->change_monitor, &priv->change_monitor_changed_handler);
       g_clear_object (&priv->change_monitor);
     }
 
@@ -694,7 +694,7 @@ ide_buffer_do_modeline (IdeBuffer *self)
   if (old_lang != NULL)
     old_id = gtk_source_language_get_id (old_lang);
 
-  if (old_id == NULL || !ide_str_equal0 (old_id, new_id))
+  if (old_id == NULL || !dzl_str_equal0 (old_id, new_id))
     _ide_file_set_content_type (ifile, content_type);
 }
 
@@ -1397,9 +1397,9 @@ ide_buffer_dispose (GObject *object)
 
   IDE_ENTRY;
 
-  ide_clear_source (&priv->settling_handler);
-  ide_clear_source (&priv->reclamation_handler);
-  ide_clear_source (&priv->check_modified_timeout);
+  dzl_clear_source (&priv->settling_handler);
+  dzl_clear_source (&priv->reclamation_handler);
+  dzl_clear_source (&priv->check_modified_timeout);
 
   if (priv->context != NULL)
     {
@@ -1421,7 +1421,7 @@ ide_buffer_dispose (GObject *object)
 
   if (priv->change_monitor != NULL)
     {
-      ide_clear_signal_handler (priv->change_monitor, &priv->change_monitor_changed_handler);
+      dzl_clear_signal_handler (priv->change_monitor, &priv->change_monitor_changed_handler);
       g_clear_object (&priv->change_monitor);
     }
 
