@@ -18,11 +18,11 @@
 
 #define G_LOG_DOMAIN "ide-buildconfig-configuration-provider"
 
+#include <dazzle.h>
 #include <gio/gio.h>
 
 #include "ide-context.h"
 #include "ide-debug.h"
-#include "ide-macros.h"
 
 #include "buildconfig/ide-buildconfig-configuration.h"
 #include "buildconfig/ide-buildconfig-configuration-provider.h"
@@ -43,7 +43,7 @@ struct _IdeBuildconfigConfigurationProvider
   GPtrArray               *configurations;
   GKeyFile                *key_file;
 
-  gulong                   writeback_handler;
+  guint                    writeback_handler;
   guint                    change_count;
 };
 
@@ -61,14 +61,14 @@ ide_buildconfig_configuration_provider_save_cb (GObject      *object,
                                                 gpointer      user_data)
 {
   g_autoptr(GTask) task = user_data;
-  GError *error = NULL;
+  g_autoptr(GError) error = NULL;
   GFile *file = (GFile *)object;
 
   g_assert (G_IS_FILE (file));
   g_assert (G_IS_ASYNC_RESULT (result));
 
   if (!g_file_replace_contents_finish (file, result, NULL, &error))
-    g_task_return_error (task, error);
+    g_task_return_error (task, g_steal_pointer (&error));
   else
     g_task_return_boolean (task, TRUE);
 }
@@ -85,13 +85,12 @@ ide_buildconfig_configuration_provider_save_async (IdeConfigurationProvider *pro
   g_auto(GStrv) groups = NULL;
   g_autoptr(GFile) file = NULL;
   g_autoptr(GBytes) bytes = NULL;
+  g_autoptr(GError) error = NULL;
   gchar *data;
-  gsize length;
+  gsize length = 0;
   IdeContext *context;
   IdeVcs *vcs;
   GFile *workdir;
-  GError *error = NULL;
-  guint i;
 
   IDE_ENTRY;
 
@@ -130,7 +129,7 @@ ide_buildconfig_configuration_provider_save_async (IdeConfigurationProvider *pro
 
   group_names = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
-  for (i = 0; i < self->configurations->len; i++)
+  for (guint i = 0; i < self->configurations->len; i++)
     {
       IdeConfiguration *configuration = g_ptr_array_index (self->configurations, i);
       IdeEnvironment *environment;
@@ -199,7 +198,7 @@ ide_buildconfig_configuration_provider_save_async (IdeConfigurationProvider *pro
           key = ide_environment_variable_get_key (var);
           value = ide_environment_variable_get_value (var);
 
-          if (!ide_str_empty0 (key))
+          if (!dzl_str_empty0 (key))
             g_key_file_set_string (self->key_file, group_environ, key, value ?: "");
         }
     }
@@ -209,7 +208,7 @@ ide_buildconfig_configuration_provider_save_async (IdeConfigurationProvider *pro
    */
   if (NULL != (groups = g_key_file_get_groups (self->key_file, NULL)))
     {
-      for (i = 0; groups [i]; i++)
+      for (guint i = 0; groups [i]; i++)
         {
           if (!g_hash_table_contains (group_names, groups [i]))
             g_key_file_remove_group (self->key_file, groups [i], NULL);
@@ -218,7 +217,7 @@ ide_buildconfig_configuration_provider_save_async (IdeConfigurationProvider *pro
 
   if (NULL == (data = g_key_file_to_data (self->key_file, &length, &error)))
     {
-      g_task_return_error (task, error);
+      g_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
@@ -231,7 +230,7 @@ ide_buildconfig_configuration_provider_save_async (IdeConfigurationProvider *pro
                                        G_FILE_CREATE_NONE,
                                        cancellable,
                                        ide_buildconfig_configuration_provider_save_cb,
-                                       g_object_ref (task));
+                                       g_steal_pointer (&task));
 
   IDE_EXIT;
 }
@@ -569,7 +568,7 @@ ide_buildconfig_configuration_provider_load_async (IdeConfigurationProvider *pro
   g_assert (IDE_IS_CONFIGURATION_MANAGER (manager));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  ide_set_weak_pointer (&self->manager, manager);
+  dzl_set_weak_pointer (&self->manager, manager);
 
   /* This task is needed so the caller knows when the load finishes */
   parent_task = g_task_new (self, cancellable, callback, user_data);
@@ -607,7 +606,7 @@ ide_buildconfig_configuration_provider_unload (IdeConfigurationProvider *provide
   g_assert (IDE_IS_BUILDCONFIG_CONFIGURATION_PROVIDER (self));
   g_assert (IDE_IS_CONFIGURATION_MANAGER (manager));
 
-  ide_clear_source (&self->writeback_handler);
+  dzl_clear_source (&self->writeback_handler);
 
   if (self->configurations != NULL)
     {
@@ -621,7 +620,7 @@ ide_buildconfig_configuration_provider_unload (IdeConfigurationProvider *provide
 
   g_clear_pointer (&self->configurations, g_ptr_array_unref);
 
-  ide_clear_weak_pointer (&self->manager);
+  dzl_clear_weak_pointer (&self->manager);
 
   IDE_EXIT;
 }
