@@ -22,17 +22,18 @@
 #include <dazzle.h>
 #include <libpeas/peas.h>
 #include <string.h>
+#include <vte/vte.h>
 
 #include "ide-context.h"
 #include "ide-debug.h"
 #include "ide-enums.h"
-#include "ide-macros.h"
 
 #include "application/ide-application.h"
 #include "buildsystem/ide-build-log.h"
 #include "buildsystem/ide-build-log-private.h"
 #include "buildsystem/ide-build-pipeline.h"
 #include "buildsystem/ide-build-pipeline-addin.h"
+#include "buildsystem/ide-build-private.h"
 #include "buildsystem/ide-build-stage.h"
 #include "buildsystem/ide-build-stage-launcher.h"
 #include "buildsystem/ide-build-stage-private.h"
@@ -44,6 +45,7 @@
 #include "plugins/ide-extension-util.h"
 #include "projects/ide-project.h"
 #include "runtimes/ide-runtime.h"
+#include "terminal/ide-terminal-util.h"
 #include "vcs/ide-vcs.h"
 
 DZL_DEFINE_COUNTER (Instances, "Pipeline", "N Pipelines", "Number of Pipeline instances")
@@ -158,6 +160,21 @@ struct _IdeBuildPipeline
   gchar  *errfmt_top_dir;
   guint   errfmt_seqnum;
 
+  /*
+   * Our PTY master for use by launchers in the build pipeline.
+   * We create a slave FD for the launchers (and dup() them when
+   * passing it to the child) that are created by pipeline addins.
+   */
+  VtePty *pty;
+  int pty_slave;
+
+  /*
+   * If the terminal interpreting our Pty has received a terminal
+   * title update, it might set this message which we can use for
+   * better build messages.
+   */
+  gchar *message;
+
   /*
    * No reference to the current stage. It is only available during
    * the asynchronous execution of the stage.
@@ -198,7 +215,7 @@ struct _IdeBuildPipeline
   guint failed : 1;
 
   /*
-   * If we are within a built, this should be set.
+   * If we are within a build, this should be set.
    */
   guint busy : 1;
 
@@ -527,7 +544,7 @@ ide_build_pipeline_log_observer (IdeBuildLogStream  stream,
         {
           gssize len;
 
-          enterdir += IDE_LITERAL_LENGTH (ENTERING_DIRECTORY_BEGIN);
+          enterdir += DZL_LITERAL_LENGTH (ENTERING_DIRECTORY_BEGIN);
 
           /* Translate to relative paths for out-of-tree builds */
           if (g_str_has_prefix (enterdir, self->builddir))
@@ -537,7 +554,7 @@ ide_build_pipeline_log_observer (IdeBuildLogStream  stream,
                 enterdir++;
             }
 
-          len = strlen (enterdir) - IDE_LITERAL_LENGTH (ENTERING_DIRECTORY_END);
+          len = strlen (enterdir) - DZL_LITERAL_LENGTH (ENTERING_DIRECTORY_END);
 
           if (len > 0)
             {
@@ -781,9 +798,9 @@ register_build_commands_stage (IdeBuildPipeline *self,
   g_assert (IDE_IS_CONTEXT (context));
   g_assert (IDE_IS_CONFIGURATION (self->configuration));
 
-  build_commands = ide_configuration_get_build_commands (self->configuration);
-  if (build_commands == NULL)
+  if (NULL == (build_commands = ide_configuration_get_build_commands (self->configuration)))
     return;
+
   for (guint i = 0; build_commands[i]; i++)
     {
       g_autoptr(IdeSubprocessLauncher) launcher = NULL;
@@ -795,6 +812,9 @@ register_build_commands_stage (IdeBuildPipeline *self,
           return;
         }
 
+      /* Request deprecation warnings from the GLib stack by default */
+      ide_subprocess_launcher_setenv (launcher, "G_ENABLE_DIAGNOSTIC", "1", FALSE);
+
       ide_subprocess_launcher_push_argv (launcher, "/bin/sh");
       ide_subprocess_launcher_push_argv (launcher, "-c");
       ide_subprocess_launcher_push_argv (launcher, build_commands[i]);
@@ -972,6 +992,15 @@ ide_build_pipeline_dispose (GObject *object)
 
   ide_build_pipeline_unload (self);
 
+  g_clear_pointer (&self->message, g_free);
+  g_clear_object (&self->pty);
+
+  if (self->pty_slave != -1)
+    {
+      close (self->pty_slave);
+      self->pty_slave = -1;
+    }
+
   G_OBJECT_CLASS (ide_build_pipeline_parent_class)->dispose (object);
 
   IDE_EXIT;
@@ -989,6 +1018,11 @@ ide_build_pipeline_initable_init (GInitable     *initable,
   g_assert (IDE_IS_BUILD_PIPELINE (self));
   g_assert (IDE_IS_CONFIGURATION (self->configuration));
 
+  /* Create a PTY for subprocess launchers */
+  self->pty = vte_pty_new_sync (VTE_PTY_DEFAULT, cancellable, error);
+  if (self->pty == NULL)
+    return FALSE;
+
   g_signal_connect_object (self->configuration,
                            "notify::ready",
                            G_CALLBACK (ide_build_pipeline_notify_ready),
@@ -1194,6 +1228,7 @@ ide_build_pipeline_init (IdeBuildPipeline *self)
   DZL_COUNTER_INC (Instances);
 
   self->position = -1;
+  self->pty_slave = -1;
 
   self->pipeline = g_array_new (FALSE, FALSE, sizeof (PipelineEntry));
   g_array_set_clear_func (self->pipeline, clear_pipeline_entry);
@@ -1352,6 +1387,9 @@ ide_build_pipeline_tick_execute (IdeBuildPipeline *self,
   g_assert (td->phase != IDE_BUILD_PHASE_NONE);
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+  /* Clear any message from the previous stage */
+  _ide_build_pipeline_set_message (self, NULL);
+
   /* Short circuit now if the task was cancelled */
   if (g_task_return_error_if_cancelled (task))
     IDE_EXIT;
@@ -1430,6 +1468,9 @@ ide_build_pipeline_task_notify_completed (IdeBuildPipeline *self,
   self->requested_mask = 0;
   self->in_clean = FALSE;
 
+  g_clear_pointer (&self->message, g_free);
+  g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_MESSAGE]);
+
   /*
    * XXX: How do we ensure transients are executed with the part of the
    *      pipeline we care about? We might just need to ensure that :busy is
@@ -1441,7 +1482,6 @@ ide_build_pipeline_task_notify_completed (IdeBuildPipeline *self,
 
   g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_BUSY]);
   g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_PHASE]);
-  g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_MESSAGE]);
 
   /*
    * We might have a delayed addin unloading that needs to occur after the
@@ -1702,6 +1742,9 @@ ide_build_pipeline_do_flush (gpointer data)
   self->position = -1;
   self->in_clean = (task_data->type == TASK_CLEAN);
 
+  /* Clear any lingering message */
+  g_clear_pointer (&self->message, g_free);
+
   /*
    * The following logs some helpful information about the build to our
    * debug log. This is useful to allow users to debug some problems
@@ -1765,6 +1808,7 @@ ide_build_pipeline_do_flush (gpointer data)
     }
 
   g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_BUSY]);
+  g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_MESSAGE]);
 
   IDE_RETURN (G_SOURCE_REMOVE);
 }
@@ -2261,6 +2305,56 @@ ide_build_pipeline_create_launcher (IdeBuildPipeline  *self,
   return g_steal_pointer (&ret);
 }
 
+/**
+ * ide_build_pipeline_attach_pty:
+ * @self: an #IdeBuildPipeline
+ * @launcher: an #IdeSubprocessLauncher
+ *
+ * Attaches a PTY to stdin/stdout/stderr of the #IdeSubprocessLauncher.
+ * This is useful if the application can take advantage of a PTY for
+ * features like colors and other escape sequences.
+ *
+ * Since: 3.28
+ */
+void
+ide_build_pipeline_attach_pty (IdeBuildPipeline      *self,
+                               IdeSubprocessLauncher *launcher)
+{
+  GSubprocessFlags flags;
+
+  g_return_if_fail (IDE_IS_BUILD_PIPELINE (self));
+  g_return_if_fail (IDE_IS_SUBPROCESS_LAUNCHER (launcher));
+
+  if (self->pty_slave == -1)
+    self->pty_slave = ide_vte_pty_create_slave (self->pty);
+
+  if (self->pty_slave == -1)
+    {
+      g_warning ("Failed to create PTY slave");
+      return;
+    }
+
+  /* Turn off built in pipes if set */
+  flags = ide_subprocess_launcher_get_flags (launcher);
+  flags &= ~(G_SUBPROCESS_FLAGS_STDERR_PIPE |
+             G_SUBPROCESS_FLAGS_STDOUT_PIPE |
+             G_SUBPROCESS_FLAGS_STDIN_PIPE);
+  ide_subprocess_launcher_set_flags (launcher, flags);
+
+  /* Assign slave device */
+  ide_subprocess_launcher_take_stdin_fd (launcher, dup (self->pty_slave));
+  ide_subprocess_launcher_take_stdout_fd (launcher, dup (self->pty_slave));
+  ide_subprocess_launcher_take_stderr_fd (launcher, dup (self->pty_slave));
+}
+
+VtePty *
+_ide_build_pipeline_get_pty (IdeBuildPipeline *self)
+{
+  g_return_val_if_fail (IDE_IS_BUILD_PIPELINE (self), NULL);
+
+  return self->pty;
+}
+
 guint
 ide_build_pipeline_add_log_observer (IdeBuildPipeline    *self,
                                      IdeBuildLogObserver  observer,
@@ -2415,14 +2509,24 @@ ide_build_pipeline_get_message (IdeBuildPipeline *self)
 
   g_return_val_if_fail (IDE_IS_BUILD_PIPELINE (self), NULL);
 
+  /* Use any message the Pty has given us while building. */
+  if (self->busy && self->message != NULL)
+    return g_strdup (self->message);
+
   if (self->in_clean)
     return g_strdup (_("Cleaning…"));
 
+  /* Not active, use simple messaging */
+  if (self->failed)
+    return g_strdup (_("Failed"));
+  else if (!self->busy)
+    return g_strdup (_("Ready"));
+
   if (self->current_stage != NULL)
     {
       const gchar *name = ide_build_stage_get_name (self->current_stage);
 
-      if (!ide_str_empty0 (name))
+      if (!dzl_str_empty0 (name))
         return g_strdup (name);
     }
 
@@ -2914,3 +3018,31 @@ ide_build_pipeline_get_can_export (IdeBuildPipeline *self)
 
   return FALSE;
 }
+
+void
+_ide_build_pipeline_set_message (IdeBuildPipeline *self,
+                                 const gchar      *message)
+{
+  g_return_if_fail (IDE_IS_BUILD_PIPELINE (self));
+
+  if (message != NULL)
+    {
+      /*
+       * Special case to deal with messages coming from systems we
+       * know prefix the build tooling information to the message.
+       * It's easier to just do this here rather than provide some
+       * sort of API for plugins to do this for us.
+       */
+      if (g_str_has_prefix (message, "flatpak-builder: "))
+        message += strlen ("flatpak-builder: ");
+      else if (g_str_has_prefix (message, "jhbuild:"))
+        message += strlen ("jhbuild:");
+    }
+
+  if (!dzl_str_equal0 (message, self->message))
+    {
+      g_free (self->message);
+      self->message = g_strdup (message);
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_MESSAGE]);
+    }
+}
