@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-build-system"
 
+#include <string.h>
+
 #include "ide-context.h"
 #include "ide-debug.h"
 #include "ide-object.h"
@@ -194,29 +196,6 @@ ide_build_system_real_get_build_flags_for_files_finish (IdeBuildSystem       *se
   return g_task_propagate_pointer (G_TASK (result), error);
 }
 
-static void
-ide_build_system_real_get_build_targets_async (IdeBuildSystem      *self,
-                                               GCancellable        *cancellable,
-                                               GAsyncReadyCallback  callback,
-                                               gpointer             user_data)
-{
-  g_task_report_new_error (self,
-                           callback,
-                           user_data,
-                           ide_build_system_real_get_build_targets_async,
-                           G_IO_ERROR,
-                           G_IO_ERROR_NOT_SUPPORTED,
-                           "Fetching build targets is not supported");
-}
-
-static GPtrArray *
-ide_build_system_real_get_build_targets_finish (IdeBuildSystem  *self,
-                                                GAsyncResult    *result,
-                                                GError         **error)
-{
-  return g_task_propagate_pointer (G_TASK (result), error);
-}
-
 static void
 ide_build_system_default_init (IdeBuildSystemInterface *iface)
 {
@@ -224,8 +203,6 @@ ide_build_system_default_init (IdeBuildSystemInterface *iface)
   iface->get_build_flags_finish = ide_build_system_real_get_build_flags_finish;
   iface->get_build_flags_for_files_async = ide_build_system_real_get_build_flags_for_files_async;
   iface->get_build_flags_for_files_finish = ide_build_system_real_get_build_flags_for_files_finish;
-  iface->get_build_targets_async = ide_build_system_real_get_build_targets_async;
-  iface->get_build_targets_finish = ide_build_system_real_get_build_targets_finish;
 
   properties [PROP_PROJECT_FILE] =
     g_param_spec_object ("project-file",
@@ -411,17 +388,15 @@ ide_build_system_post_process_build_flags (IdeBuildSystem  *self,
             }
           break;
 
-        case 'f': /* -fPIC */
-        case 'W': /* -Werror... */
-        case 'm': /* -m64 -mtune=native */
-          break;
-
         case 'D':
         case 'x':
           if (strlen (flag) == 2)
             i++;
           break;
 
+        case 'f': /* -fPIC */
+        case 'W': /* -Werror... */
+        case 'm': /* -m64 -mtune=native */
         default:
           break;
         }
@@ -523,45 +498,6 @@ ide_build_system_get_build_flags_for_files_finish (IdeBuildSystem       *self,
   IDE_RETURN (ret);
 }
 
-void
-ide_build_system_get_build_targets_async (IdeBuildSystem      *self,
-                                          GCancellable        *cancellable,
-                                          GAsyncReadyCallback  callback,
-                                          gpointer             user_data)
-{
-  IDE_ENTRY;
-
-  g_return_if_fail (IDE_IS_BUILD_SYSTEM (self));
-  g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
-
-  IDE_BUILD_SYSTEM_GET_IFACE (self)->get_build_targets_async (self, cancellable, callback, user_data);
-
-  IDE_EXIT;
-}
-
-/**
- * ide_build_system_get_build_targets_finish:
- *
- * Returns: (transfer container) (element-type Ide.BuildTarget): An array
- *   of #IdeBuildTarget or %NULL and @error is set.
- */
-GPtrArray *
-ide_build_system_get_build_targets_finish (IdeBuildSystem  *self,
-                                           GAsyncResult    *result,
-                                           GError         **error)
-{
-  GPtrArray *ret;
-
-  IDE_ENTRY;
-
-  g_return_val_if_fail (IDE_IS_BUILD_SYSTEM (self), NULL);
-  g_return_val_if_fail (G_IS_TASK (result), NULL);
-
-  ret = IDE_BUILD_SYSTEM_GET_IFACE (self)->get_build_targets_finish (self, result, error);
-
-  IDE_RETURN (ret);
-}
-
 gchar *
 ide_build_system_get_builddir (IdeBuildSystem   *self,
                                IdeConfiguration *configuration)
@@ -579,29 +515,19 @@ ide_build_system_get_builddir (IdeBuildSystem   *self,
   if (ret == NULL)
     {
       g_autofree gchar *name = NULL;
-      const gchar *project_id;
       const gchar *config_id;
       const gchar *device_id;
       const gchar *runtime_id;
       IdeContext *context;
-      IdeProject *project;
 
       context = ide_object_get_context (IDE_OBJECT (self));
-      project = ide_context_get_project (context);
-      project_id = ide_project_get_id (project);
       config_id = ide_configuration_get_id (configuration);
       device_id = ide_configuration_get_device_id (configuration);
       runtime_id = ide_configuration_get_runtime_id (configuration);
 
       name = g_strdelimit (g_strdup_printf ("%s-%s-%s", config_id, device_id, runtime_id),
                            "@:/", '-');
-
-      ret = g_build_filename (g_get_user_cache_dir (),
-                              "gnome-builder",
-                              "builds",
-                              project_id,
-                              name,
-                              NULL);
+      ret = ide_context_cache_filename (context, "builds", name, NULL);
     }
 
   IDE_RETURN (ret);
