@@ -24,8 +24,6 @@
 #include <libpeas/peas.h>
 #include <pango/pangofc-fontmap.h>
 
-#include "ide-macros.h"
-
 #include "buffers/ide-buffer-private.h"
 #include "editor/ide-editor-private.h"
 #include "sourceview/ide-line-change-gutter-renderer.h"
@@ -113,7 +111,16 @@ ide_editor_view_notify_child_revealed (IdeEditorView *self,
   g_assert (GTK_IS_REVEALER (revealer));
 
   if (gtk_revealer_get_child_revealed (revealer))
-    gtk_widget_grab_focus (GTK_WIDGET (self->search_bar));
+    {
+      GtkWidget *toplevel = gtk_widget_get_ancestor (GTK_WIDGET (revealer), GTK_TYPE_WINDOW);
+      GtkWidget *focus = gtk_window_get_focus (GTK_WINDOW (toplevel));
+
+      /* Only focus the search bar if it doesn't already have focus,
+       * as it can reselect the search text.
+       */
+      if (focus == NULL || !gtk_widget_is_ancestor (focus, GTK_WIDGET (revealer)))
+        gtk_widget_grab_focus (GTK_WIDGET (self->search_bar));
+    }
 }
 
 static void
@@ -778,7 +785,7 @@ ide_editor_view_destroy (GtkWidget *widget)
 
   g_assert (IDE_IS_EDITOR_VIEW (self));
 
-  ide_clear_source (&self->toggle_map_source);
+  dzl_clear_source (&self->toggle_map_source);
 
   g_clear_object (&self->addins);
 
@@ -1160,7 +1167,7 @@ ide_editor_view_update_reveal_timer (IdeEditorView *self)
 {
   g_assert (IDE_IS_EDITOR_VIEW (self));
 
-  ide_clear_source (&self->toggle_map_source);
+  dzl_clear_source (&self->toggle_map_source);
 
   if (self->auto_hide_map && gtk_revealer_get_reveal_child (self->map_revealer))
     {
