@@ -23,7 +23,6 @@
 #include <libpeas/peas.h>
 
 #include "ide-debug.h"
-#include "ide-macros.h"
 
 #include "application/ide-application.h"
 #include "genesis/ide-genesis-addin.h"
@@ -114,20 +113,19 @@ ide_perspective_iface_init (IdePerspectiveInterface *iface)
 }
 
 static void
-ide_greeter_perspective_activate_cb (PeasExtensionSet *set,
-                                     PeasPluginInfo   *plugin_info,
-                                     PeasExtension    *exten,
-                                     gpointer          user_data)
+ide_greeter_perspective_activate_cb (GtkWidget *widget,
+                                     gpointer   user_data)
 {
-  IdeGreeterSection *section = (IdeGreeterSection *)exten;
   gboolean *handled = user_data;
 
-  g_assert (PEAS_IS_EXTENSION_SET (set));
-  g_assert (plugin_info != NULL);
-  g_assert (IDE_IS_GREETER_SECTION (section));
+  g_assert (GTK_IS_WIDGET (widget));
+  g_assert (handled != NULL);
+
+  if (!IDE_IS_GREETER_SECTION (widget))
+    return;
 
   if (!*handled)
-    *handled = ide_greeter_section_activate_first (section);
+    *handled = ide_greeter_section_activate_first (IDE_GREETER_SECTION (widget));
 }
 
 static void
@@ -139,9 +137,9 @@ ide_greeter_perspective__search_entry_activate (IdeGreeterPerspective *self,
   g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
   g_assert (GTK_IS_SEARCH_ENTRY (search_entry));
 
-  peas_extension_set_foreach (self->sections,
-                              ide_greeter_perspective_activate_cb,
-                              &handled);
+  gtk_container_foreach (GTK_CONTAINER (self->sections_container),
+                         ide_greeter_perspective_activate_cb,
+                         &handled);
 
   if (!handled)
     gdk_window_beep (gtk_widget_get_window (GTK_WIDGET (search_entry)));
@@ -299,6 +297,7 @@ ide_greeter_perspective_open_clicked (IdeGreeterPerspective *self,
   PeasEngine *engine;
   const GList *list;
   GtkFileFilter *all_filter;
+  gint64 last_priority = G_MAXINT64;
 
   g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
   g_assert (GTK_IS_BUTTON (open_button));
@@ -340,6 +339,7 @@ ide_greeter_perspective_open_clicked (IdeGreeterPerspective *self,
       const gchar *pattern;
       const gchar *content_type;
       const gchar *name;
+      const gchar *priority;
       gchar **patterns;
       gchar **content_types;
       gint i;
@@ -353,6 +353,7 @@ ide_greeter_perspective_open_clicked (IdeGreeterPerspective *self,
 
       pattern = peas_plugin_info_get_external_data (plugin_info, "X-Project-File-Filter-Pattern");
       content_type = peas_plugin_info_get_external_data (plugin_info, "X-Project-File-Filter-Content-Type");
+      priority = peas_plugin_info_get_external_data (plugin_info, "X-Project-File-Filter-Priority");
 
       if (pattern == NULL && content_type == NULL)
         continue;
@@ -391,6 +392,18 @@ ide_greeter_perspective_open_clicked (IdeGreeterPerspective *self,
 
       gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
 
+      /* Look at the priority to set the default file filter. */
+      if (priority != NULL)
+        {
+          gint64 pval = g_ascii_strtoll (priority, NULL, 10);
+
+          if (pval < last_priority)
+            {
+              gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
+              last_priority = pval;
+            }
+        }
+
       g_strfreev (patterns);
       g_strfreev (content_types);
     }
@@ -401,7 +414,9 @@ ide_greeter_perspective_open_clicked (IdeGreeterPerspective *self,
                            self,
                            G_CONNECT_SWAPPED);
 
-  gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), all_filter);
+  /* If unset, set the default filter */
+  if (last_priority == G_MAXINT64)
+    gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), all_filter);
 
   settings = g_settings_new ("org.gnome.builder");
   projects_dir = g_settings_get_string (settings, "projects-directory");
@@ -678,7 +693,7 @@ update_title_for_matching_addin (PeasExtensionSet *set,
 
       if (binding != NULL)
         {
-          ide_clear_weak_pointer (&state->self->ready_binding);
+          dzl_clear_weak_pointer (&state->self->ready_binding);
           g_binding_unbind (binding);
         }
 
@@ -687,7 +702,7 @@ update_title_for_matching_addin (PeasExtensionSet *set,
                                         state->self->genesis_continue_button,
                                         "sensitive",
                                         G_BINDING_SYNC_CREATE);
-      ide_set_weak_pointer (&state->self->ready_binding, binding);
+      dzl_set_weak_pointer (&state->self->ready_binding, binding);
 
       gtk_label_set_label (state->self->genesis_title, title);
       gtk_button_set_label (state->self->genesis_continue_button, next);
@@ -934,7 +949,10 @@ ide_greeter_perspective_notify_has_selection (IdeGreeterPerspective *self,
                               ide_greeter_perspective_notify_has_selection_cb,
                               &has_selection);
 
-  dzl_gtk_widget_action_set (GTK_WIDGET (self), "greeter", "delete-selected-rows",
+  dzl_gtk_widget_action_set (GTK_WIDGET (self), "greeter", "remove-selected-rows",
+                             "enabled", has_selection,
+                             NULL);
+  dzl_gtk_widget_action_set (GTK_WIDGET (self), "greeter", "purge-selected-rows",
                              "enabled", has_selection,
                              NULL);
 }
@@ -1042,7 +1060,7 @@ ide_greeter_perspective_constructed (GObject *object)
 }
 
 static void
-delete_selected_rows_cb (PeasExtensionSet *set,
+remove_selected_rows_cb (PeasExtensionSet *set,
                          PeasPluginInfo   *plugin_info,
                          PeasExtension    *exten,
                          gpointer          user_data)
@@ -1057,7 +1075,7 @@ delete_selected_rows_cb (PeasExtensionSet *set,
 }
 
 static void
-delete_selected_rows (GSimpleAction *simple,
+remove_selected_rows (GSimpleAction *simple,
                       GVariant      *param,
                       gpointer       user_data)
 {
@@ -1067,13 +1085,88 @@ delete_selected_rows (GSimpleAction *simple,
 
   g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
 
-  peas_extension_set_foreach (self->sections, delete_selected_rows_cb, NULL);
+  peas_extension_set_foreach (self->sections, remove_selected_rows_cb, NULL);
   ide_greeter_perspective_apply_filter_all (self);
   dzl_state_machine_set_state (self->state_machine, "browse");
 
   IDE_EXIT;
 }
 
+static void
+purge_selected_rows_cb (PeasExtensionSet *set,
+                        PeasPluginInfo   *plugin_info,
+                        PeasExtension    *exten,
+                        gpointer          user_data)
+{
+  IdeGreeterSection *section = (IdeGreeterSection *)exten;
+
+  g_assert (PEAS_IS_EXTENSION_SET (set));
+  g_assert (plugin_info != NULL);
+  g_assert (IDE_IS_GREETER_SECTION (section));
+
+  ide_greeter_section_purge_selected (section);
+}
+
+static void
+purge_selected_rows_response (IdeGreeterPerspective *self,
+                              gint                   response,
+                              GtkDialog             *dialog)
+{
+  IDE_ENTRY;
+
+  g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
+  g_assert (GTK_IS_MESSAGE_DIALOG (dialog));
+
+  if (response == GTK_RESPONSE_OK)
+    {
+      peas_extension_set_foreach (self->sections, purge_selected_rows_cb, NULL);
+      ide_greeter_perspective_apply_filter_all (self);
+      dzl_state_machine_set_state (self->state_machine, "browse");
+    }
+
+  gtk_widget_destroy (GTK_WIDGET (dialog));
+
+  IDE_EXIT;
+}
+
+static void
+purge_selected_rows (GSimpleAction *simple,
+                     GVariant      *param,
+                     gpointer       user_data)
+{
+  IdeGreeterPerspective *self = user_data;
+  GtkDialog *dialog;
+  GtkWidget *parent;
+  GtkWidget *button;
+
+  IDE_ENTRY;
+
+  g_assert (IDE_IS_GREETER_PERSPECTIVE (self));
+
+  parent = gtk_widget_get_ancestor (GTK_WIDGET (self), GTK_TYPE_WINDOW);
+  dialog = g_object_new (GTK_TYPE_MESSAGE_DIALOG,
+                         "modal", TRUE,
+                         "transient-for", parent,
+                         "attached-to", parent,
+                         "text", _("Removing project files will delete them from your computer and cannot be undone."),
+                         NULL);
+  gtk_dialog_add_buttons (dialog,
+                          _("Cancel"), GTK_RESPONSE_CANCEL,
+                          _("Delete Project Files"), GTK_RESPONSE_OK,
+                          NULL);
+  button = gtk_dialog_get_widget_for_response (dialog, GTK_RESPONSE_OK);
+  dzl_gtk_widget_add_style_class (button, "destructive-action");
+  g_signal_connect_data (dialog,
+                         "response",
+                         G_CALLBACK (purge_selected_rows_response),
+                         g_object_ref (self),
+                         (GClosureNotify)g_object_unref,
+                         G_CONNECT_SWAPPED);
+  gtk_window_present (GTK_WINDOW (dialog));
+
+  IDE_EXIT;
+}
+
 static void
 ide_greeter_perspective_notify_selection (PeasExtensionSet *set,
                                           PeasPluginInfo   *plugin_info,
@@ -1123,7 +1216,7 @@ ide_greeter_perspective_finalize (GObject *object)
 {
   IdeGreeterPerspective *self = (IdeGreeterPerspective *)object;
 
-  ide_clear_weak_pointer (&self->ready_binding);
+  dzl_clear_weak_pointer (&self->ready_binding);
   g_clear_pointer (&self->pattern_spec, dzl_pattern_spec_unref);
   g_clear_object (&self->cancellable);
 
@@ -1166,7 +1259,8 @@ ide_greeter_perspective_class_init (IdeGreeterPerspectiveClass *klass)
 }
 
 static const GActionEntry actions[] = {
-  { "delete-selected-rows", delete_selected_rows },
+  { "purge-selected-rows", purge_selected_rows },
+  { "remove-selected-rows", remove_selected_rows },
 };
 
 static void
@@ -1242,7 +1336,10 @@ ide_greeter_perspective_init (IdeGreeterPerspective *self)
   g_action_map_add_action_entries (G_ACTION_MAP (group), actions, G_N_ELEMENTS (actions), self);
   gtk_widget_insert_action_group (GTK_WIDGET (self), "greeter", G_ACTION_GROUP (group));
 
-  dzl_gtk_widget_action_set (GTK_WIDGET (self), "greeter", "delete-selected-rows",
+  dzl_gtk_widget_action_set (GTK_WIDGET (self), "greeter", "remove-selected-rows",
+                             "enabled", FALSE,
+                             NULL);
+  dzl_gtk_widget_action_set (GTK_WIDGET (self), "greeter", "purge-selected-rows",
                              "enabled", FALSE,
                              NULL);
 }
