@@ -109,6 +109,7 @@ struct _IdeContext
   IdeDoap                  *doap;
   IdeDocumentation         *documentation;
   GListStore               *pausables;
+  DzlRecursiveFileMonitor  *monitor;
   GtkRecentManager         *recent_manager;
   IdeRunManager            *run_manager;
   IdeRuntimeManager        *runtime_manager;
@@ -117,7 +118,6 @@ struct _IdeContext
   IdeTestManager           *test_manager;
   IdeProject               *project;
   GFile                    *project_file;
-  gchar                    *root_build_dir;
   gchar                    *recent_projects_path;
   PeasExtensionSet         *services;
   GHashTable               *services_by_gtype;
@@ -148,7 +148,6 @@ enum {
   PROP_DOCUMENTATION,
   PROP_PROJECT_FILE,
   PROP_PROJECT,
-  PROP_ROOT_BUILD_DIR,
   PROP_RUNTIME_MANAGER,
   PROP_SEARCH_ENGINE,
   PROP_SNIPPETS_MANAGER,
@@ -259,47 +258,6 @@ ide_context_get_documentation (IdeContext *self)
   return self->documentation;
 }
 
-
-/**
- * ide_context_get_root_build_dir:
- *
- * Retrieves the "root-build-dir" for the context. This is the root directory
- * that will contain builds made for various devices.
- *
- * Returns: A string containing the "root-build-dir" property.
- */
-const gchar *
-ide_context_get_root_build_dir (IdeContext *self)
-{
-  g_return_val_if_fail (IDE_IS_CONTEXT (self), NULL);
-
-  return self->root_build_dir;
-}
-
-/**
- * ide_context_set_root_build_dir:
- * @root_build_dir: the path to the root build directory.
- *
- * Sets the "root-build-dir" property. This is the root directory that will
- * be used when building projects for projects that support building out of
- * tree.
- */
-void
-ide_context_set_root_build_dir (IdeContext  *self,
-                                const gchar *root_build_dir)
-{
-  g_return_if_fail (IDE_IS_CONTEXT (self));
-  g_return_if_fail (root_build_dir);
-
-  if (self->root_build_dir != root_build_dir)
-    {
-      g_free (self->root_build_dir);
-      self->root_build_dir = g_strdup (root_build_dir);
-      g_object_notify_by_pspec (G_OBJECT (self),
-                                properties [PROP_ROOT_BUILD_DIR]);
-    }
-}
-
 /**
  * ide_context_get_snippets_manager:
  *
@@ -541,6 +499,7 @@ ide_context_dispose (GObject *object)
   IDE_ENTRY;
 
   g_list_store_remove_all (self->pausables);
+  dzl_recursive_file_monitor_cancel (self->monitor);
 
   G_OBJECT_CLASS (ide_context_parent_class)->dispose (object);
 
@@ -556,10 +515,10 @@ ide_context_finalize (GObject *object)
 
   g_clear_object (&self->services);
   g_clear_object (&self->pausables);
+  g_clear_object (&self->monitor);
 
   g_clear_pointer (&self->build_system_hint, g_free);
   g_clear_pointer (&self->services_by_gtype, g_hash_table_unref);
-  g_clear_pointer (&self->root_build_dir, g_free);
   g_clear_pointer (&self->recent_projects_path, g_free);
 
   g_clear_object (&self->build_system);
@@ -622,10 +581,6 @@ ide_context_get_property (GObject    *object,
       g_value_set_object (value, ide_context_get_project_file (self));
       break;
 
-    case PROP_ROOT_BUILD_DIR:
-      g_value_set_string (value, ide_context_get_root_build_dir (self));
-      break;
-
     case PROP_RUNTIME_MANAGER:
       g_value_set_object (value, ide_context_get_runtime_manager (self));
       break;
@@ -665,10 +620,6 @@ ide_context_set_property (GObject      *object,
       ide_context_set_project_file (self, g_value_get_object (value));
       break;
 
-    case PROP_ROOT_BUILD_DIR:
-      ide_context_set_root_build_dir (self, g_value_get_string (value));
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -735,13 +686,6 @@ ide_context_class_init (IdeContextClass *klass)
                           G_PARAM_CONSTRUCT_ONLY |
                           G_PARAM_STATIC_STRINGS));
 
-  properties [PROP_ROOT_BUILD_DIR] =
-    g_param_spec_string ("root-build-dir",
-                         "Root Build Directory",
-                         "The root directory to perform builds within.",
-                         NULL,
-                         (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-
   properties [PROP_RUNTIME_MANAGER] =
     g_param_spec_object ("runtime-manager",
                          "Runtime Manager",
@@ -809,11 +753,6 @@ ide_context_init (IdeContext *self)
 
   self->recent_manager = g_object_ref (gtk_recent_manager_get_default ());
 
-  self->root_build_dir = g_build_filename (g_get_user_cache_dir (),
-                                           ide_get_program_name (),
-                                           "builds",
-                                           NULL);
-
   self->recent_projects_path = g_build_filename (g_get_user_data_dir (),
                                                  ide_get_program_name (),
                                                  IDE_RECENT_PROJECTS_BOOKMARK_FILENAME,
@@ -906,7 +845,7 @@ ide_context_load_doap_worker (GTask        *task,
 
           filename = g_file_info_get_name (file_info);
 
-          if (!ide_str_empty0 (filename) && g_str_has_suffix (filename, ".doap"))
+          if (!dzl_str_empty0 (filename) && g_str_has_suffix (filename, ".doap"))
             {
               g_autoptr(GFile) file = NULL;
               g_autoptr(IdeDoap) doap = NULL;
@@ -2458,3 +2397,148 @@ _ide_context_get_pausables (IdeContext *self)
 
   return G_LIST_MODEL (self->pausables);
 }
+
+/**
+ * ide_context_cache_file:
+ * @self: a #IdeContext
+ * @first_part: The first part of the path
+ *
+ * Like ide_context_cache_filename() but returns a #GFile.
+ *
+ * Returns: (transfer full): a #GFile for the cache file
+ *
+ * Since: 3.28
+ */
+GFile *
+ide_context_cache_file (IdeContext  *self,
+                        const gchar *first_part,
+                        ...)
+{
+  g_autoptr(GPtrArray) ar = NULL;
+  g_autofree gchar *path = NULL;
+  const gchar *part = first_part;
+  va_list args;
+
+  g_return_val_if_fail (IDE_IS_CONTEXT (self), NULL);
+  g_return_val_if_fail (first_part != NULL, NULL);
+
+  ar = g_ptr_array_new ();
+  g_ptr_array_add (ar, (gchar *)g_get_user_cache_dir ());
+  g_ptr_array_add (ar, (gchar *)ide_get_program_name ());
+  g_ptr_array_add (ar, (gchar *)"projects");
+  g_ptr_array_add (ar, (gchar *)ide_project_get_id (self->project));
+
+  va_start (args, first_part);
+  do
+    {
+      g_ptr_array_add (ar, (gchar *)part);
+      part = va_arg (args, const gchar *);
+    }
+  while (part != NULL);
+  va_end (args);
+
+  g_ptr_array_add (ar, NULL);
+
+  path = g_build_filenamev ((gchar **)ar->pdata);
+
+  return g_file_new_for_path (path);
+}
+
+/**
+ * ide_context_cache_filename:
+ * @self: a #IdeContext
+ * @first_part: the first part of the filename
+ *
+ * Creates a new filename that will be located in the projects cache directory.
+ * This makes it convenient to remove files when a project is deleted as all
+ * cache files will share a unified parent directory.
+ *
+ * The file will be located in a directory similar to
+ * ~/.cache/gnome-builder/project_name. This may change based on the value
+ * of g_get_user_cache_dir().
+ *
+ * Returns: (transfer full): A new string containing the cache filename
+ *
+ * Since: 3.28
+ */
+gchar *
+ide_context_cache_filename (IdeContext  *self,
+                            const gchar *first_part,
+                            ...)
+{
+  g_autoptr(GPtrArray) ar = NULL;
+  const gchar *part = first_part;
+  va_list args;
+
+  g_return_val_if_fail (IDE_IS_CONTEXT (self), NULL);
+  g_return_val_if_fail (first_part != NULL, NULL);
+
+  ar = g_ptr_array_new ();
+  g_ptr_array_add (ar, (gchar *)g_get_user_cache_dir ());
+  g_ptr_array_add (ar, (gchar *)ide_get_program_name ());
+  g_ptr_array_add (ar, (gchar *)"projects");
+  g_ptr_array_add (ar, (gchar *)ide_project_get_id (self->project));
+
+  va_start (args, first_part);
+  do
+    {
+      g_ptr_array_add (ar, (gchar *)part);
+      part = va_arg (args, const gchar *);
+    }
+  while (part != NULL);
+  va_end (args);
+
+  g_ptr_array_add (ar, NULL);
+
+  return g_build_filenamev ((gchar **)ar->pdata);
+}
+
+static gboolean
+ide_context_ignore_func (GFile    *file,
+                         gpointer  data)
+{
+  IdeContext *self = data;
+
+  g_assert (G_IS_FILE (file));
+  g_assert (IDE_IS_CONTEXT (self));
+
+  return ide_vcs_is_ignored (self->vcs, file, NULL);
+}
+
+/**
+ * ide_context_get_monitor:
+ * @self: a #IdeContext
+ *
+ * Gets a #DzlRecursiveFileMonitor that monitors the project directory
+ * recursively. You can use this to track changes across the project
+ * tree without creating your own #GFileMonitor.
+ *
+ * Returns: (transfer none): a #DzlRecursiveFileMonitor to monitor the
+ *   project tree.
+ *
+ * Since: 3.28
+ */
+DzlRecursiveFileMonitor *
+ide_context_get_monitor (IdeContext *self)
+{
+  g_return_val_if_fail (IDE_IS_CONTEXT (self), NULL);
+
+  if (self->monitor == NULL)
+    {
+      g_autoptr(GFile) root = NULL;
+
+      if (g_file_query_file_type (self->project_file, 0, NULL) == G_FILE_TYPE_DIRECTORY)
+        root = g_object_ref (self->project_file);
+      else
+        root = g_file_get_parent (self->project_file);
+
+      self->monitor = dzl_recursive_file_monitor_new (root);
+      dzl_recursive_file_monitor_set_ignore_func (self->monitor,
+                                                  ide_context_ignore_func,
+                                                  g_object_ref (self),
+                                                  g_object_unref);
+      dzl_recursive_file_monitor_start_async (self->monitor, NULL, NULL, NULL);
+    }
+
+  return self->monitor;
+}
