@@ -18,6 +18,7 @@
 
 #pragma once
 
+#include <dazzle.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
@@ -72,8 +73,6 @@ IdeUnsavedFiles          *ide_context_get_unsaved_files         (IdeContext
 IDE_AVAILABLE_IN_ALL
 IdeVcs                   *ide_context_get_vcs                   (IdeContext           *self);
 IDE_AVAILABLE_IN_ALL
-const gchar              *ide_context_get_root_build_dir        (IdeContext           *self);
-IDE_AVAILABLE_IN_ALL
 gpointer                  ide_context_get_service_typed         (IdeContext           *self,
                                                                  GType                 service_type);
 IDE_AVAILABLE_IN_ALL
@@ -94,9 +93,6 @@ IDE_AVAILABLE_IN_ALL
 IdeContext               *ide_context_new_finish                (GAsyncResult         *result,
                                                                  GError              **error);
 IDE_AVAILABLE_IN_ALL
-void                      ide_context_set_root_build_dir        (IdeContext           *self,
-                                                                 const gchar          *root_build_dir);
-IDE_AVAILABLE_IN_ALL
 void                      ide_context_restore_async             (IdeContext           *self,
                                                                  GCancellable         *cancellable,
                                                                  GAsyncReadyCallback   callback,
@@ -122,6 +118,17 @@ IDE_AVAILABLE_IN_ALL
 void                      ide_context_warning                   (IdeContext           *self,
                                                                  const gchar          *format,
                                                                  ...) G_GNUC_PRINTF (2, 3);
+IDE_AVAILABLE_IN_3_28
+GFile                    *ide_context_cache_file                (IdeContext           *self,
+                                                                 const gchar          *first_part,
+                                                                 ...) G_GNUC_NULL_TERMINATED;
+IDE_AVAILABLE_IN_3_28
+gchar                    *ide_context_cache_filename            (IdeContext           *self,
+                                                                 const gchar          *first_part,
+                                                                 ...) G_GNUC_NULL_TERMINATED;
+IDE_AVAILABLE_IN_3_28
+DzlRecursiveFileMonitor  *ide_context_get_monitor               (IdeContext           *self);
+
 GListModel               *_ide_context_get_pausables            (IdeContext           *self) G_GNUC_INTERNAL;
 gboolean                  _ide_context_is_restoring             (IdeContext           *self) G_GNUC_INTERNAL;
 
