@@ -30,7 +30,6 @@ G_BEGIN_DECLS
 #include "ide-debug.h"
 #include "ide-enums.h"
 #include "ide-global.h"
-#include "ide-macros.h"
 #include "ide-object.h"
 #include "ide-pausable.h"
 #include "ide-service.h"
@@ -58,6 +57,7 @@ G_BEGIN_DECLS
 #include "buildsystem/ide-build-system.h"
 #include "buildsystem/ide-build-system-discovery.h"
 #include "buildsystem/ide-build-target.h"
+#include "buildsystem/ide-build-target-provider.h"
 #include "buildsystem/ide-compile-commands.h"
 #include "buildsystem/ide-configuration-manager.h"
 #include "buildsystem/ide-configuration.h"
@@ -144,6 +144,7 @@ G_BEGIN_DECLS
 #include "search/ide-search-provider.h"
 #include "search/ide-search-reducer.h"
 #include "search/ide-search-result.h"
+#include "search/ide-tagged-entry.h"
 #include "snippets/ide-source-snippet-chunk.h"
 #include "snippets/ide-source-snippet-context.h"
 #include "snippets/ide-source-snippet.h"
@@ -170,6 +171,9 @@ G_BEGIN_DECLS
 #include "testing/ide-test-manager.h"
 #include "testing/ide-test-provider.h"
 #include "threading/ide-thread-pool.h"
+#include "terminal/ide-terminal.h"
+#include "terminal/ide-terminal-search.h"
+#include "terminal/ide-terminal-util.h"
 #include "transfers/ide-pkcon-transfer.h"
 #include "transfers/ide-transfer.h"
 #include "transfers/ide-transfer-button.h"
@@ -177,6 +181,7 @@ G_BEGIN_DECLS
 #include "util/ide-cell-renderer-fancy.h"
 #include "util/ide-fancy-tree-view.h"
 #include "util/ide-flatpak.h"
+#include "util/ide-glib.h"
 #include "util/ide-gtk.h"
 #include "util/ide-line-reader.h"
 #include "util/ide-list-inline.h"
@@ -185,6 +190,7 @@ G_BEGIN_DECLS
 #include "util/ide-ref-ptr.h"
 #include "util/ide-uri.h"
 #include "vcs/ide-vcs-config.h"
+#include "vcs/ide-vcs-file-info.h"
 #include "vcs/ide-vcs-initializer.h"
 #include "vcs/ide-vcs-uri.h"
 #include "vcs/ide-vcs.h"
