@@ -20,8 +20,6 @@
 
 #include <glib/gi18n.h>
 
-#include "ide-macros.h"
-
 #include "layout/ide-layout-private.h"
 #include "layout/ide-layout-stack-header.h"
 
@@ -479,7 +477,7 @@ ide_layout_stack_header_destroy (GtkWidget *widget)
 
   g_assert (IDE_IS_LAYOUT_STACK_HEADER (self));
 
-  ide_clear_source (&self->update_css_handler);
+  dzl_clear_source (&self->update_css_handler);
   g_clear_object (&self->css_provider);
 
   if (self->title_list_box != NULL)
