@@ -18,6 +18,9 @@
 
 #define G_LOG_DOMAIN "ide-runtime"
 
+#include <dazzle.h>
+#include <string.h>
+
 #include "ide-context.h"
 #include "ide-debug.h"
 
@@ -164,9 +167,9 @@ ide_runtime_real_create_runner (IdeRuntime     *self,
                                 IdeBuildTarget *build_target)
 {
   IdeRuntimePrivate *priv = ide_runtime_get_instance_private (self);
-  g_autofree gchar *name = NULL;
   g_autoptr(GFile) installdir = NULL;
-  const gchar *slash;
+  g_auto(GStrv) argv = NULL;
+  g_autofree gchar *cwd = NULL;
   IdeContext *context;
   IdeRunner *runner;
 
@@ -179,56 +182,88 @@ ide_runtime_real_create_runner (IdeRuntime     *self,
   runner = ide_runner_new (context);
   g_assert (IDE_IS_RUNNER (runner));
 
-  if (ide_str_equal0 (priv->id, "host"))
+  if (dzl_str_equal0 (priv->id, "host"))
     ide_runner_set_run_on_host (runner, TRUE);
 
   if (build_target != NULL)
-    g_object_get (build_target,
-                  "install-directory", &installdir,
-                  "name", &name,
-                  NULL);
-
-  /* Targets might be relative in autotools */
-  if (name != NULL && NULL != (slash = strrchr (name, '/')))
     {
-      gchar *tmp = g_strdup (slash + 1);
-      g_free (name);
-      name = tmp;
+      ide_runner_set_build_target (runner, build_target);
+
+      installdir = ide_build_target_get_install_directory (build_target);
+      argv = ide_build_target_get_argv (build_target);
+      cwd = ide_build_target_get_cwd (build_target);
+    }
+
+  /* Possibly translate relative paths for the binary */
+  if (argv && argv[0] && !g_path_is_absolute (argv[0]))
+    {
+      const gchar *slash = strchr (argv[0], '/');
+      g_autofree gchar *copy = g_strdup (slash ? (slash + 1) : argv[0]);
+
+      g_free (argv[0]);
+
+      if (installdir != NULL)
+        {
+          g_autoptr(GFile) dest = g_file_get_child (installdir, copy);
+          argv[0] = g_file_get_path (dest);
+        }
+      else
+        argv[0] = g_steal_pointer (&copy);
     }
 
   if (installdir != NULL)
     {
       g_autoptr(GFile) parentdir = NULL;
-      g_autoptr(GFile) bin = NULL;
       g_autofree gchar *schemadir = NULL;
       g_autofree gchar *parentpath = NULL;
-      g_autofree gchar *binpath = NULL;
 
       /* GSettings requires an env var for non-standard dirs */
       if (NULL != (parentdir = g_file_get_parent (installdir)))
         {
-          IdeEnvironment *env;
+          IdeEnvironment *env = ide_runner_get_environment (runner);
 
           parentpath = g_file_get_path (parentdir);
           schemadir = g_build_filename (parentpath, "share", "glib-2.0", "schemas", NULL);
-
-          env = ide_runner_get_environment (runner);
           ide_environment_setenv (env, "GSETTINGS_SCHEMA_DIR", schemadir);
         }
-
-      bin = g_file_get_child (installdir, name);
-      binpath = g_file_get_path (bin);
-
-      ide_runner_append_argv (runner, binpath);
-    }
-  else if (name != NULL)
-    {
-      ide_runner_append_argv (runner, name);
     }
 
+  if (argv != NULL)
+    ide_runner_push_args (runner, (const gchar * const *)argv);
+
+  if (cwd != NULL)
+    ide_runner_set_cwd (runner, cwd);
+
   return runner;
 }
 
+static GFile *
+ide_runtime_real_translate_file (IdeRuntime *self,
+                                 GFile      *file)
+{
+  g_autofree gchar *path = NULL;
+
+  g_assert (IDE_IS_RUNTIME (self));
+  g_assert (G_IS_FILE (file));
+
+  /* We only need to translate when running as flatpak */
+  if (!ide_is_flatpak ())
+    return NULL;
+
+  /* Only deal with native files */
+  if (!g_file_is_native (file) || NULL == (path = g_file_get_path (file)))
+    return NULL;
+
+  /* If this is /usr or /etc, then translate to /run/host/$dir,
+   * as that is where flatpak 0.10.1 and greater will mount them
+   * when --filesystem=host.
+   */
+  if (g_str_has_prefix (path, "/usr/") || g_str_has_prefix (path, "/etc/"))
+    return g_file_new_build_filename ("/run/host/", path, NULL);
+
+  return NULL;
+}
+
 static void
 ide_runtime_finalize (GObject *object)
 {
@@ -300,6 +335,7 @@ ide_runtime_class_init (IdeRuntimeClass *klass)
   klass->create_runner = ide_runtime_real_create_runner;
   klass->contains_program_in_path = ide_runtime_real_contains_program_in_path;
   klass->prepare_configuration = ide_runtime_real_prepare_configuration;
+  klass->translate_file = ide_runtime_real_translate_file;
 
   properties [PROP_ID] =
     g_param_spec_string ("id",
@@ -487,3 +523,28 @@ ide_runtime_translate_file (IdeRuntime *self,
 
   return ret;
 }
+
+/**
+ * ide_runtime_get_system_include_dirs:
+ * @self: a #IdeRuntime
+ *
+ * Gets the system include dirs for the runtime. Usually, this is just
+ * "/usr/include", but more complex runtimes may include additional.
+ *
+ * Returns: (transfer full) (array zero-terminated=1): A newly allocated
+ *   string containing the include dirs.
+ *
+ * Since: 3.28
+ */
+gchar **
+ide_runtime_get_system_include_dirs (IdeRuntime *self)
+{
+  static const gchar *basic[] = { "/usr/include", NULL };
+
+  g_return_val_if_fail (IDE_IS_RUNTIME (self), NULL);
+
+  if (IDE_RUNTIME_GET_CLASS (self)->get_system_include_dirs)
+    return IDE_RUNTIME_GET_CLASS (self)->get_system_include_dirs (self);
+
+  return g_strdupv ((gchar **)basic);
+}
