@@ -19,7 +19,6 @@
 #define G_LOG_DOMAIN "ide-search-entry"
 
 #include "ide-context.h"
-#include "ide-macros.h"
 
 #include "editor/ide-editor-perspective.h"
 #include "search/ide-search-engine.h"
@@ -36,6 +35,12 @@ struct _IdeSearchEntry
   guint max_results;
 };
 
+typedef struct
+{
+  IdeEditorPerspective *editor;
+  IdeSourceLocation    *location;
+} DelayedActivate;
+
 G_DEFINE_TYPE (IdeSearchEntry, ide_search_entry, DZL_TYPE_SUGGESTION_ENTRY)
 
 enum {
@@ -95,7 +100,7 @@ ide_search_entry_changed (IdeSearchEntry *self)
 
   typed_text = dzl_suggestion_entry_get_typed_text (DZL_SUGGESTION_ENTRY (self));
 
-  if (ide_str_empty0 (typed_text))
+  if (dzl_str_empty0 (typed_text))
     {
       dzl_suggestion_entry_set_model (DZL_SUGGESTION_ENTRY (self), NULL);
       return;
@@ -111,6 +116,30 @@ ide_search_entry_changed (IdeSearchEntry *self)
                                   g_object_ref (self));
 }
 
+static void
+delayed_activate_free (gpointer data)
+{
+  DelayedActivate *da = data;
+
+  g_clear_object (&da->editor);
+  g_clear_pointer (&da->location, ide_source_location_unref);
+  g_slice_free (DelayedActivate, da);
+}
+
+static gboolean
+delayed_activate_handle (gpointer data)
+{
+  DelayedActivate *da = data;
+
+  g_assert (da != NULL);
+  g_assert (IDE_IS_EDITOR_PERSPECTIVE (da->editor));
+  g_assert (da->location != NULL);
+
+  ide_editor_perspective_focus_location (da->editor, da->location);
+
+  return G_SOURCE_REMOVE;
+}
+
 static void
 suggestion_activated (DzlSuggestionEntry *entry,
                       DzlSuggestion      *suggestion)
@@ -124,10 +153,29 @@ suggestion_activated (DzlSuggestionEntry *entry,
 
   if (location != NULL)
     {
-      IdeWorkbench *workbench = ide_widget_get_workbench (GTK_WIDGET (entry));
-      IdePerspective *perspective = ide_workbench_get_perspective_by_name (workbench, "editor");
+      IdeWorkbench *workbench;
+      IdePerspective *perspective;
+      DelayedActivate *da;
 
-      ide_editor_perspective_focus_location (IDE_EDITOR_PERSPECTIVE (perspective), location);
+      workbench = ide_widget_get_workbench (GTK_WIDGET (entry));
+      perspective = ide_workbench_get_perspective_by_name (workbench, "editor");
+
+      /*
+       * The goal here is to wait a short bit of time before activating the
+       * item so that our window has a chance to animate out. Otherwise, we
+       * get a jittery animation because the UI is likely doing too much work
+       * (such as creating and sink'ing the new widgetry).
+       */
+
+      da = g_slice_new0 (DelayedActivate);
+      da->editor = g_object_ref (IDE_EDITOR_PERSPECTIVE (perspective));
+      da->location = g_steal_pointer (&location);
+
+      gdk_threads_add_timeout_full (G_PRIORITY_LOW,
+                                    250,
+                                    delayed_activate_handle,
+                                    g_steal_pointer (&da),
+                                    delayed_activate_free);
     }
 }
 
