@@ -22,7 +22,6 @@
 #include <glib/gi18n.h>
 
 #include "ide-debug.h"
-#include "ide-macros.h"
 
 #include "snippets/ide-source-snippet.h"
 #include "snippets/ide-source-snippet-private.h"
@@ -835,7 +834,7 @@ ide_source_snippet_rewrite_updated_chunks (IdeSourceSnippet *self)
       text = ide_source_snippet_chunk_get_text (chunk);
       real_text = ide_source_snippet_get_nth_text (self, i);
 
-      if (!ide_str_equal0 (text, real_text))
+      if (!dzl_str_equal0 (text, real_text))
         ide_source_snippet_replace_chunk_text (self, i, text);
     }
 }
