@@ -129,6 +129,8 @@ typedef enum
  * @IDE_SOURCE_VIEW_MOVEMENT_SCROLL_SCREEN_RIGHT: scroll until insert cursor or [count]th char is at screen right.
  * @IDE_SOURCE_VIEW_MOVEMENT_NEXT_MATCH_SEARCH_CHAR: move to the next matching char according to f and t in vim.
  * @IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_MATCH_SEARCH_CHAR: move to the previous matching char according to F and T in vim.
+ * @IDE_SOURCE_VIEW_MOVEMENT_SMART_HOME: Moves to the first non-whitespace character unless
+ *   already positioned there. Otherwise, it moves to the first character.
  *
  * The type of movement.
  *
@@ -224,8 +226,18 @@ typedef enum
 
   IDE_SOURCE_VIEW_MOVEMENT_NEXT_MATCH_SEARCH_CHAR,
   IDE_SOURCE_VIEW_MOVEMENT_PREVIOUS_MATCH_SEARCH_CHAR,
+
+  IDE_SOURCE_VIEW_MOVEMENT_SMART_HOME,
 } IdeSourceViewMovement;
 
+typedef enum
+{
+  IDE_SOURCE_SCROLL_NONE = 0,
+  IDE_SOURCE_SCROLL_BOTH = 1,
+  IDE_SOURCE_SCROLL_X    = 1 << 1,
+  IDE_SOURCE_SCROLL_Y    = 1 << 2,
+} IdeSourceScrollAlign;
+
 struct _IdeSourceViewClass
 {
   GtkSourceViewClass parent_class;
@@ -466,14 +478,14 @@ void                        ide_source_view_clear_search              (IdeSource
 IDE_AVAILABLE_IN_ALL
 void                        ide_source_view_scroll_mark_onscreen      (IdeSourceView              *self,
                                                                        GtkTextMark                *mark,
-                                                                       gboolean                    use_align,
+                                                                       IdeSourceScrollAlign        use_align,
                                                                        gdouble                     alignx,
                                                                        gdouble                     aligny);
 IDE_AVAILABLE_IN_ALL
 void                        ide_source_view_scroll_to_mark            (IdeSourceView              *self,
                                                                        GtkTextMark                *mark,
                                                                        gdouble                     within_margin,
-                                                                       gboolean                    use_align,
+                                                                       IdeSourceScrollAlign        use_align,
                                                                        gdouble                     xalign,
                                                                        gdouble                     yalign,
                                                                        gboolean                    animate_scroll);
@@ -481,7 +493,7 @@ IDE_AVAILABLE_IN_ALL
 void                        ide_source_view_scroll_to_iter            (IdeSourceView              *self,
                                                                        const GtkTextIter          *iter,
                                                                        gdouble                     within_margin,
-                                                                       gboolean                    use_align,
+                                                                       IdeSourceScrollAlign        use_align,
                                                                        gdouble                     xalign,
                                                                        gdouble                     yalign,
                                                                        gboolean                    animate_scroll);
