@@ -18,11 +18,11 @@
 
 #define G_LOG_DOMAIN "ide-word-completion-provider"
 
+#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <string.h>
 
 #include "ide-debug.h"
-#include "ide-macros.h"
 
 #include "sourceview/ide-word-completion-provider.h"
 #include "sourceview/ide-word-completion-item.h"
@@ -314,7 +314,7 @@ completion_cleanup (IdeWordCompletionProvider *self)
 
   if (priv->context != NULL)
     {
-      ide_clear_signal_handler (priv->context, &priv->cancel_id);
+      dzl_clear_signal_handler (priv->context, &priv->cancel_id);
 
       g_clear_object (&priv->context);
     }
