@@ -32,7 +32,6 @@
 #include <unistd.h>
 
 #include "ide-debug.h"
-#include "ide-macros.h"
 
 #include "application/ide-application.h"
 #include "subprocess/ide-breakout-subprocess.h"
@@ -672,15 +671,14 @@ ide_subprocess_communicate_made_progress (GObject      *source_object,
 {
   CommunicateState *state;
   IdeBreakoutSubprocess *subprocess;
-  GError *error = NULL;
+  g_autoptr(GError) error = NULL;
+  g_autoptr(GTask) task = user_data;
   gpointer source;
-  GTask *task;
 
   IDE_ENTRY;
 
   g_assert (source_object != NULL);
 
-  task = user_data;
   subprocess = g_task_get_source_object (task);
   state = g_task_get_task_data (task);
   source = source_object;
@@ -691,18 +689,17 @@ ide_subprocess_communicate_made_progress (GObject      *source_object,
       source == state->stdout_buf ||
       source == state->stderr_buf)
     {
-      if (g_output_stream_splice_finish ((GOutputStream*) source, result, &error) == -1)
+      if (g_output_stream_splice_finish (source, result, &error) == -1)
         goto out;
 
-      if (source == state->stdout_buf ||
-          source == state->stderr_buf)
+      if (source == state->stdout_buf || source == state->stderr_buf)
         {
           /* This is a memory stream, so it can't be cancelled or return
            * an error really.
            */
           if (state->add_nul)
             {
-              gsize bytes_written;
+              gsize bytes_written = 0;
               if (!g_output_stream_write_all (source, "\0", 1, &bytes_written, NULL, &error))
                 goto out;
             }
@@ -718,7 +715,7 @@ ide_subprocess_communicate_made_progress (GObject      *source_object,
     g_assert_not_reached ();
 
  out:
-  if (error)
+  if (error != NULL)
     {
       /* Only report the first error we see.
        *
@@ -729,19 +726,14 @@ ide_subprocess_communicate_made_progress (GObject      *source_object,
         {
           state->reported_error = TRUE;
           g_cancellable_cancel (state->cancellable);
-          ide_g_task_return_error_from_main (task, error);
+          ide_g_task_return_error_from_main (task, g_steal_pointer (&error));
         }
-      else
-        g_error_free (error);
     }
   else if (state->outstanding_ops == 0)
     {
       ide_g_task_return_boolean_from_main (task, TRUE);
     }
 
-  /* And drop the original ref */
-  g_object_unref (task);
-
   IDE_EXIT;
 }
 
@@ -1071,8 +1063,8 @@ ide_breakout_subprocess_complete_command_locked (IdeBreakoutSubprocess *self,
   g_clear_pointer (&self->identifier, g_free);
 
   /* Remove our sources used for signal propagation */
-  ide_clear_source (&self->sigint_id);
-  ide_clear_source (&self->sigterm_id);
+  dzl_clear_source (&self->sigint_id);
+  dzl_clear_source (&self->sigterm_id);
 
   /* Complete async workers */
   waiting = self->waiting;
@@ -1587,8 +1579,8 @@ ide_breakout_subprocess_dispose (GObject *object)
   if (self->waiting != NULL)
     g_warning ("improper disposal while async operations are active!");
 
-  ide_clear_source (&self->sigint_id);
-  ide_clear_source (&self->sigterm_id);
+  dzl_clear_source (&self->sigint_id);
+  dzl_clear_source (&self->sigterm_id);
 
   G_OBJECT_CLASS (ide_breakout_subprocess_parent_class)->dispose (object);
 }
