@@ -705,12 +705,7 @@ ide_clang_translation_unit_code_complete_worker (GTask        *task,
   ar = g_ptr_array_new_with_free_func (g_object_unref);
 
   for (i = 0; i < results->NumResults; i++)
-    {
-      GtkSourceCompletionProposal *proposal;
-
-      proposal = GTK_SOURCE_COMPLETION_PROPOSAL (ide_clang_completion_item_new (refptr, i));
-      g_ptr_array_add (ar, proposal);
-    }
+    g_ptr_array_add (ar, ide_clang_completion_item_new (refptr, i));
 
   g_task_return_pointer (task, ar, (GDestroyNotify)g_ptr_array_unref);
 
@@ -894,7 +889,6 @@ ide_clang_translation_unit_lookup_symbol (IdeClangTranslationUnit  *self,
                                           IdeSourceLocation        *location,
                                           GError                  **error)
 {
-  g_autofree gchar *filename = NULL;
   g_autofree gchar *workpath = NULL;
   g_auto(CXString) cxstr = { 0 };
   g_autoptr(IdeSourceLocation) declaration = NULL;
