@@ -82,7 +82,9 @@ create_palette_close_dialog (GbColorPickerPrefs *self,
 
   toplevel = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (self->panel)));
   palette_name = gstyle_palette_get_name (palette);
-  text = g_strdup_printf ("Save changes to palette “%s” before closing ?", palette_name);
+  /* translators: %s is replaced with the name of the color palette. */
+  text = g_strdup_printf (_("Save changes to palette “%s” before closing?"),
+                          palette_name);
   dialog = g_object_new (GTK_TYPE_MESSAGE_DIALOG,
                          "text", text,
                          "message-type", GTK_MESSAGE_QUESTION,
@@ -125,7 +127,7 @@ string_to_variant (const gchar *str)
   GVariant *variant;
   g_autoptr(GError) error = NULL;
 
-  g_assert (!ide_str_empty0 (str));
+  g_assert (!dzl_str_empty0 (str));
 
   variant = g_variant_parse (NULL, str, NULL, NULL, &error);
   if (variant == NULL)
@@ -542,13 +544,13 @@ gb_color_picker_prefs_set_panel (GbColorPickerPrefs *self,
           gb_color_picker_prefs_unbind_settings (self);
           gstyle_color_panel_set_prefs_pages (self->panel, NULL, NULL, NULL, NULL);
           gtk_list_box_bind_model (GTK_LIST_BOX (self->palettes_listbox), NULL, NULL, NULL, NULL);
-          ide_clear_weak_pointer (&self->panel);
+          dzl_clear_weak_pointer (&self->panel);
           self->palette_widget = NULL;
         }
 
       if (panel != NULL && GSTYLE_IS_COLOR_PANEL (panel))
         {
-          ide_set_weak_pointer (&self->panel, panel);
+          dzl_set_weak_pointer (&self->panel, panel);
           self->palette_widget = gstyle_color_panel_get_palette_widget (self->panel);
           self->palettes_store = gstyle_palette_widget_get_store (self->palette_widget);
           gtk_list_box_bind_model (GTK_LIST_BOX (self->palettes_listbox),
@@ -631,7 +633,7 @@ gb_color_picker_prefs_finalize (GObject *object)
 {
   GbColorPickerPrefs *self = (GbColorPickerPrefs *)object;
 
-  ide_clear_weak_pointer (&self->panel);
+  dzl_clear_weak_pointer (&self->panel);
 
   g_clear_object (&self->components_page);
   g_clear_object (&self->color_strings_page);
