@@ -61,13 +61,13 @@ ide_ctags_service_build_index_init_cb (GObject      *object,
 {
   IdeCtagsIndex *index = (IdeCtagsIndex *)object;
   g_autoptr(GTask) task = user_data;
-  GError *error = NULL;
+  g_autoptr(GError) error = NULL;
 
   g_assert (IDE_IS_CTAGS_INDEX (index));
   g_assert (G_IS_TASK (task));
 
   if (!g_async_initable_init_finish (G_ASYNC_INITABLE (index), result, &error))
-    g_task_return_error (task, error);
+    g_task_return_error (task, g_steal_pointer (&error));
   else if (ide_ctags_index_get_is_empty (index))
     g_task_return_new_error (task,
                              G_IO_ERROR,
@@ -384,7 +384,6 @@ ide_ctags_service_do_mine (gpointer data)
   g_autoptr(GArray) mine_info = NULL;
   g_autofree gchar *path = NULL;
   IdeContext *context;
-  IdeProject *project;
   MineInfo info;
   GFile *workdir;
 
@@ -396,18 +395,13 @@ ide_ctags_service_do_mine (gpointer data)
   self->miner_active = TRUE;
 
   context = ide_object_get_context (IDE_OBJECT (self));
-  project = ide_context_get_project (context);
   workdir = ide_vcs_get_working_directory (ide_context_get_vcs (context));
 
   mine_info = g_array_new (FALSE, FALSE, sizeof (MineInfo));
   g_array_set_clear_func (mine_info, clear_mine_info);
 
-  /* mine: ~/.cache/gnome-builder/tags/$project_id */
-  info.path = g_build_filename (g_get_user_cache_dir (),
-                                ide_get_program_name (),
-                                "tags",
-                                ide_project_get_id (project),
-                                NULL);
+  /* mine: ~/.cache/gnome-builder/projects/$project_id/ctags/ */
+  info.path = ide_context_cache_filename (context, "ctags", NULL);
   info.recursive = TRUE;
   g_array_append_val (mine_info, info);
 
