@@ -40,7 +40,7 @@ struct _GbpFlatpakConfigurationProvider
   GPtrArray               *configurations;
   GPtrArray               *manifest_monitors;
 
-  gulong                   writeback_handler;
+  guint                    writeback_handler;
   guint                    change_count;
 };
 
@@ -61,7 +61,6 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                                                 GCancellable *cancellable)
 {
   GbpFlatpakConfigurationProvider *self = source_object;
-  GError *error = NULL;
 
   IDE_ENTRY;
 
@@ -88,6 +87,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
       g_auto(GStrv) new_config_opts = NULL;
       g_auto(GStrv) new_runtime_parts = NULL;
       g_auto(GStrv) new_environ = NULL;
+      g_autoptr(GError) error = NULL;
       g_autofree gchar *primary_module_regex_str = NULL;
       g_autofree gchar *primary_module_right_curly_brace = NULL;
       g_autofree gchar *right_curly_brace_line = NULL;
@@ -128,7 +128,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
       file_stream = g_file_read (manifest, NULL, &error);
       if (file_stream == NULL)
         {
-          g_task_return_error (task, error);
+          g_task_return_error (task, g_steal_pointer (&error));
           IDE_EXIT;
         }
 
@@ -153,7 +153,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
         }
 
       new_config_opts_string = g_strdup (ide_configuration_get_config_opts (IDE_CONFIGURATION (configuration)));
-      if (!ide_str_empty0 (new_config_opts_string))
+      if (!dzl_str_empty0 (new_config_opts_string))
         new_config_opts = g_strsplit (g_strstrip (new_config_opts_string), " ", 0);
 
       new_environ = ide_configuration_get_environ (IDE_CONFIGURATION (configuration));
@@ -182,7 +182,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
           line = g_data_input_stream_read_line_utf8 (data_stream, NULL, NULL, &error);
           if (error != NULL)
             {
-              g_task_return_error (task, error);
+              g_task_return_error (task, g_steal_pointer (&error));
               IDE_EXIT;
             }
 
@@ -211,7 +211,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
             }
 
           /* Replace the runtime with the user-chosen one */
-          if (!ide_str_empty0 (new_runtime_name))
+          if (!dzl_str_empty0 (new_runtime_name))
             {
               g_autoptr(GMatchInfo) match_info = NULL;
 
@@ -232,7 +232,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
             }
 
           /* Replace the runtime version with the user-chosen one */
-          if (!ide_str_empty0 (new_runtime_version))
+          if (!dzl_str_empty0 (new_runtime_version))
             {
               g_autoptr(GMatchInfo) match_info = NULL;
 
@@ -296,7 +296,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                       /* We're at the closing curly brace for build-options */
                       guint num_env;
                       num_env = g_strv_length (new_environ);
-                      if (num_env > 0 || !ide_str_empty0 (new_prefix))
+                      if (num_env > 0 || !dzl_str_empty0 (new_prefix))
                         {
                           g_autofree gchar *cflags_line = NULL;
                           g_autofree gchar *cxxflags_line = NULL;
@@ -342,7 +342,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                             {
                               gchar *line_ending;
 
-                              line_ending = (!ide_str_empty0 (new_prefix) || cxxflags_line != NULL || env_lines != NULL) ? "," : "";
+                              line_ending = (!dzl_str_empty0 (new_prefix) || cxxflags_line != NULL || env_lines != NULL) ? "," : "";
                               g_ptr_array_add (new_lines, g_strdup_printf ("%s%s", cflags_line, line_ending));
                             }
 
@@ -350,11 +350,11 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                             {
                               gchar *line_ending;
 
-                              line_ending = (!ide_str_empty0 (new_prefix) || env_lines != NULL) ? "," : "";
+                              line_ending = (!dzl_str_empty0 (new_prefix) || env_lines != NULL) ? "," : "";
                               g_ptr_array_add (new_lines, g_strdup_printf ("%s%s", cxxflags_line, line_ending));
                             }
 
-                          if (!ide_str_empty0 (new_prefix))
+                          if (!dzl_str_empty0 (new_prefix))
                             {
                               gchar *line_ending;
 
@@ -459,7 +459,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                   next_line = g_data_input_stream_read_line_utf8 (data_stream, NULL, NULL, &error);
                   if (error != NULL)
                     {
-                      g_task_return_error (task, error);
+                      g_task_return_error (task, g_steal_pointer (&error));
                       IDE_EXIT;
                     }
                   if (g_str_has_prefix (next_line, primary_module_right_curly_brace))
@@ -558,7 +558,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                                     cancellable,
                                     &error))
         {
-          g_task_return_error (task, error);
+          g_task_return_error (task, g_steal_pointer (&error));
           IDE_EXIT;
         }
     }
@@ -659,7 +659,7 @@ contains_id (GPtrArray   *ar,
 
       g_assert (IDE_IS_CONFIGURATION (configuration));
 
-      if (ide_str_equal0 (id, ide_configuration_get_id (configuration)))
+      if (dzl_str_equal0 (id, ide_configuration_get_id (configuration)))
         return TRUE;
     }
 
@@ -674,7 +674,7 @@ get_manifest_id (const gchar *path,
   g_autofree gchar *hash = NULL;
   gsize manifest_data_len = 0;
 
-  g_assert (!ide_str_empty0 (path));
+  g_assert (!dzl_str_empty0 (path));
 
   if (g_file_get_contents (path, &manifest_data, &manifest_data_len, NULL))
     {
@@ -751,7 +751,9 @@ gbp_flatpak_configuration_provider_manifest_changed (GbpFlatpakConfigurationProv
       else
         g_clear_pointer (&filename, g_free);
       new_config_file = other_file;
-      IDE_FALLTHROUGH;
+#if G_GNUC_CHECK_VERSION(7,0)
+      __attribute__((fallthrough));
+#endif
     case G_FILE_MONITOR_EVENT_CREATED:
     case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
     case G_FILE_MONITOR_EVENT_MOVED_IN:
@@ -1018,8 +1020,8 @@ gbp_flatpak_configuration_provider_load_cb (GObject      *object,
                                             gpointer      user_data)
 {
   GbpFlatpakConfigurationProvider *self = (GbpFlatpakConfigurationProvider *)object;
+  g_autoptr(GError) error = NULL;
   GPtrArray *ret;
-  GError *error = NULL;
   guint i;
   g_autoptr(GTask) task = user_data;
 
@@ -1068,7 +1070,7 @@ gbp_flatpak_configuration_provider_load_async (IdeConfigurationProvider *provide
   g_assert (IDE_IS_CONFIGURATION_MANAGER (manager));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-  ide_set_weak_pointer (&self->manager, manager);
+  dzl_set_weak_pointer (&self->manager, manager);
 
   self->manifest_monitors = g_ptr_array_new_with_free_func (g_object_unref);
 
@@ -1103,7 +1105,7 @@ gbp_flatpak_configuration_provider_unload (IdeConfigurationProvider *provider,
   g_assert (GBP_IS_FLATPAK_CONFIGURATION_PROVIDER (self));
   g_assert (IDE_IS_CONFIGURATION_MANAGER (manager));
 
-  ide_clear_source (&self->writeback_handler);
+  dzl_clear_source (&self->writeback_handler);
 
   if (self->configurations != NULL)
     {
@@ -1119,7 +1121,7 @@ gbp_flatpak_configuration_provider_unload (IdeConfigurationProvider *provider,
 
   g_clear_pointer (&self->manifest_monitors, g_ptr_array_unref);
 
-  ide_clear_weak_pointer (&self->manager);
+  dzl_clear_weak_pointer (&self->manager);
 
   IDE_EXIT;
 }
