@@ -21,7 +21,6 @@
 #include <libgit2-glib/ggit.h>
 #include <ide.h>
 
-#include "ide-macros.h"
 #include "ide-git-clone-widget.h"
 #include "ide-git-remote-callbacks.h"
 
@@ -238,7 +237,7 @@ ide_git_clone_widget_init (IdeGitCloneWidget *self)
   settings = g_settings_new ("org.gnome.builder");
   path = g_settings_get_string (settings, "projects-directory");
 
-  if (ide_str_empty0 (path))
+  if (dzl_str_empty0 (path))
     path = g_build_filename (g_get_home_dir (), "Projects", NULL);
 
   if (!g_path_is_absolute (path))
@@ -333,13 +332,13 @@ ide_git_clone_widget_worker (GTask        *task,
 {
   g_autofree gchar *uristr = NULL;
   IdeGitCloneWidget *self = source_object;
+  g_autoptr(GError) error = NULL;
   GgitRepository *repository;
-  CloneRequest *req = task_data;
   GgitCloneOptions *clone_options;
   GgitFetchOptions *fetch_options;
   GgitRemoteCallbacks *callbacks;
+  CloneRequest *req = task_data;
   IdeProgress *progress;
-  GError *error = NULL;
 
   g_assert (G_IS_TASK (task));
   g_assert (IDE_IS_GIT_CLONE_WIDGET (self));
@@ -373,7 +372,7 @@ ide_git_clone_widget_worker (GTask        *task,
 
   if (repository == NULL)
     {
-      g_task_return_error (task, error);
+      g_task_return_error (task, g_steal_pointer (&error));
       return;
     }
 
