@@ -99,6 +99,9 @@ class JsSymbolTree(GObject.Object, Ide.SymbolTree):
             for dec in dict_['declarations']:
                 line = max(dec['id']['loc']['start']['line'] - 1, 0)
                 col = dec['id']['loc']['start']['column']
+                if dec['id']['type'] != 'Identifier':
+                    # destructured assignment, ignore
+                    return
                 name = dec['id']['name']
                 kind = Ide.SymbolKind.VARIABLE
                 children = []
@@ -148,9 +151,33 @@ class JsSymbolTree(GObject.Object, Ide.SymbolTree):
                                 kind=Ide.SymbolKind.METHOD,
                                 name=name,
                                 file=file_)
+        elif type_ == 'ExpressionStatement' and JsSymbolTree._is_module_exports(dict_):
+            if dict_['expression']['right']['type'] != 'ClassExpression':
+                return None
+            class_ = dict_['expression']['right']
+            children = JsSymbolTree._nodes_from_list(class_['body'], file_)
+            line = max(class_['loc']['start']['line'] - 1, 0)
+            col = class_['loc']['start']['column']
+            return JsSymbolNode(children, line=line, col=col,
+                                kind=Ide.SymbolKind.CLASS,
+                                name=class_['id']['name'],
+                                file=file_)
         else:
             return None
 
+    @staticmethod
+    def _is_module_exports(dict_):
+        if dict_['expression']['type'] != 'AssignmentExpression':
+            return False
+        left = dict_['expression']['left']
+        if left['type'] != 'MemberExpression':
+            return False
+        if left['object']['type'] != 'Identifier' or left['object']['name'] != 'module':
+            return False
+        if left['property']['type'] != 'Identifier' or left['property']['name'] != 'exports':
+            return False
+        return True
+
     @staticmethod
     def _is_module_import(dict_):
         try:
@@ -159,7 +186,10 @@ class JsSymbolTree(GObject.Object, Ide.SymbolTree):
             try:
                 return dict_['init']['object']['object']['name'] == 'imports'
             except (KeyError, TypeError):
-                return False
+                try:
+                    return dict_['init']['callee']['name'] == 'require'
+                except (KeyError, TypeError):
+                    return False
 
     @staticmethod
     def _is_gobject_class(dict_):
@@ -326,9 +356,6 @@ class GjsCodeIndexer(Ide.Object, Ide.CodeIndexer):
         return nodes
 
     def do_index_file(self, file_, build_flags, cancellable):
-        if 'node_modules' in file_.get_path().split(os.sep):
-            return None  # Avoid indexing these
-
         launcher = GjsSymbolProvider._get_launcher(self.get_context(), file_)
         proc = launcher.spawn()
         success, stdout, stderr = proc.communicate_utf8(None, None)
