@@ -20,6 +20,7 @@
 #include <ide.h>
 
 #include "gbp-meson-build-system.h"
+#include "gbp-meson-build-target-provider.h"
 #include "gbp-meson-pipeline-addin.h"
 #include "gbp-meson-test-provider.h"
 
@@ -28,5 +29,6 @@ gbp_meson_register_types (PeasObjectModule *module)
 {
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_PIPELINE_ADDIN, GBP_TYPE_MESON_PIPELINE_ADDIN);
   peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_SYSTEM, GBP_TYPE_MESON_BUILD_SYSTEM);
+  peas_object_module_register_extension_type (module, IDE_TYPE_BUILD_TARGET_PROVIDER, GBP_TYPE_MESON_BUILD_TARGET_PROVIDER);
   peas_object_module_register_extension_type (module, IDE_TYPE_TEST_PROVIDER, GBP_TYPE_MESON_TEST_PROVIDER);
 }
