@@ -18,6 +18,7 @@
 
 #define G_LOG_DOMAIN "xml-completion"
 
+#include <dazzle.h>
 #include <libpeas/peas.h>
 
 #include "ide-xml-completion-provider.h"
@@ -99,10 +100,11 @@ populate_state_free (PopulateState *state)
 {
   g_assert (state != NULL);
 
-  g_object_unref (state->self);
-  g_object_unref (state->ifile);
-  g_object_unref (state->buffer);
-  g_object_unref (state->cancellable);
+  g_clear_object (&state->self);
+  g_clear_object (&state->ifile);
+  g_clear_object (&state->buffer);
+  g_clear_object (&state->cancellable);
+  g_slice_free (PopulateState, state);
 }
 
 static GPtrArray *
@@ -374,7 +376,7 @@ completion_item_new (const gchar     *label,
 {
   CompletionItem *item;
 
-  g_assert (!ide_str_empty0 (label));
+  g_assert (!dzl_str_empty0 (label));
   g_assert (define != NULL);
 
   item = g_slice_new0 (CompletionItem);
@@ -503,7 +505,7 @@ is_define_equal_node (IdeXmlRngDefine  *define,
   g_assert (define != NULL);
   g_assert (IDE_IS_XML_SYMBOL_NODE (node));
 
-  return ide_str_equal0 (ide_xml_symbol_node_get_element_name (node), define->name);
+  return dzl_str_equal0 (ide_xml_symbol_node_get_element_name (node), define->name);
 }
 
 static gboolean
@@ -516,7 +518,7 @@ is_element_matching (MatchingState *state)
   g_assert (state->define->type == IDE_XML_RNG_DEFINE_ELEMENT);
 
   /* XXX: we skip element without a name for now */
-  if (ide_str_empty0 ((gchar *)state->define->name))
+  if (dzl_str_empty0 ((gchar *)state->define->name))
     return FALSE;
 
   if (state->children->len == 0)
@@ -528,7 +530,7 @@ is_element_matching (MatchingState *state)
   if (state->candidate_node == node)
     {
       name = (gchar *)state->define->name;
-      if (ide_str_empty0 (state->prefix) || g_str_has_prefix ((gchar *)state->define->name, state->prefix))
+      if (dzl_str_empty0 (state->prefix) || g_str_has_prefix ((gchar *)state->define->name, state->prefix))
         {
           state->candidate_node = NULL;
           state->retry = TRUE;
@@ -847,7 +849,7 @@ get_values_proposals (IdeXmlPosition  *position,
   GList *results = NULL;
 
   node = ide_xml_position_get_child_node (position);
-  g_assert (!ide_str_empty0 (position->detail_name));
+  g_assert (!dzl_str_empty0 (position->detail_name));
 
   if (NULL != (attributes = ide_xml_completion_attributes_get_matches (define, node, FALSE)))
     {
@@ -862,7 +864,7 @@ get_values_proposals (IdeXmlPosition  *position,
       for (gint j = 0; j < attributes->len; ++j)
         {
           match_item = g_ptr_array_index (attributes, j);
-          if (ide_str_equal0 (detail_name, match_item->name))
+          if (dzl_str_equal0 (detail_name, match_item->name))
             {
               attr_define = match_item->define;
               break;
@@ -1040,7 +1042,7 @@ ide_xml_completion_provider_populate (GtkSourceCompletionProvider *self,
 
   buffer = IDE_BUFFER (gtk_text_iter_get_buffer (&iter));
 
-  state->self = g_object_ref (self);
+  state->self = g_object_ref (IDE_XML_COMPLETION_PROVIDER (self));
   state->completion_context = completion_context;
   state->cancellable = g_cancellable_new ();
   state->buffer = g_object_ref (buffer);
